﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Diagnostics;
using System.ServiceModel;
using WamGrid_Select_2Events.WebService;

namespace WamGrid_Select_2Events
{
    public class ViewModel : INotifyPropertyChanged
    {
        #region PropertyChanged
        public event PropertyChangedEventHandler PropertyChanged;

        private void NotifyPropertyChanged(String info)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(info));
            }
        }
        #endregion

        private ObservableCollection<T_Person> _elements;
        public ObservableCollection<T_Person> Elements
        {
            get { return _elements; }
            set { 
                _elements = value;
                this.NotifyPropertyChanged("Elements");
            }
        }

        private T_Person _oneElement;
        public T_Person OneElement
        {
            get { return _oneElement; }
            set {
                _oneElement = value;
                this.NotifyPropertyChanged("OneElement");

                if (value != null)
                {
                    this.LoadData();
                }
            
            }
        }

        private bool _isEnabled;
        public bool IsEnabled
        {
            get { return _isEnabled; }
            set
            {
                _isEnabled = value;
                this.NotifyPropertyChanged("IsEnabled");
            }
        }

        private bool _isBusy;
        public bool IsBusy
        {
            get { return _isBusy; }
            set
            {
                _isBusy = value;
                this.NotifyPropertyChanged("IsBusy");
            }
        }


        /// <summary>
        /// Loading data from database : can take som time....
        /// </summary>
        public void LoadData()
        {
            // 1rst element has been selected => no BusyIndicator, no focus change, no WebService call      
            if (this.OneElement == this.Elements[0])
            {
                Debug.WriteLine("--- LoadData() : Start loading data");
                Debug.WriteLine("--- LoadData() : End loading data");
            }
            // 2nd element has been selected => no BusyIndicator, no focus change, WITH WebService call 
            else if(this.OneElement == this.Elements[1])
            {
                Debug.WriteLine("--- LoadData() : Start loading data");
                WebServiceSoapClient webService = new WebServiceSoapClient();
                webService.SleepingServiceCompleted += new EventHandler<SleepingServiceCompletedEventArgs>(webService_SleepingServiceCompleted);
                webService.SleepingServiceAsync();
            }
            // 3rd element has been selected => WITH BusyIndicator, WITH focus change, WITH WebService call 
            else if (this.OneElement == this.Elements[2])
            {
                Debug.WriteLine("--- LoadData() : Start loading data");
                this.IsBusy = true;
                WebServiceSoapClient webService = new WebServiceSoapClient();
                webService.SleepingServiceCompleted += new EventHandler<SleepingServiceCompletedEventArgs>(webService_SleepingServiceCompleted);
                webService.SleepingServiceAsync();
            }
        }

        void webService_SleepingServiceCompleted(object sender, SleepingServiceCompletedEventArgs e)
        {
            // 1rst element has been selected => no BusyIndicator, no focus change, no WebService call
            if (this.OneElement == this.Elements[0])
            {
            }
            // 2nd element has been selected => no BusyIndicator, no focus change, WITH WebService call
            else if (this.OneElement == this.Elements[1])
            {
                Debug.WriteLine("--- webService.SleepingServiceAsync() return : " + e.Result);
                Debug.WriteLine("--- LoadData() : End loading data");
            }
            // 3rd element has been selected => WITH BusyIndicator, WITH focus change, WITH WebService call
            else if (this.OneElement == this.Elements[2])
            {
                this.IsBusy = false;
                Debug.WriteLine("--- webService.SleepingServiceAsync() return : " + e.Result);
                Debug.WriteLine("--- LoadData() : End loading data");
            }
        }

    }
}
